@@ -459,6 +459,63 @@ chmod 755 /tmp/whp-backups
 
 echo "✓ Backup system directories created"
 
+# Setup WebSocket Terminal Server
+echo ""
+echo "======================================"
+echo "Setting up WebSocket Terminal Server..."
+
+# Install Node.js via NVM if not present
+if ! command -v node &> /dev/null; then
+    echo "Installing Node.js 22 LTS via NVM..."
+    
+    # Download and install nvm
+    curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.40.3/install.sh | bash
+    
+    # Source nvm for current session
+    export NVM_DIR="$HOME/.nvm"
+    [ -s "$NVM_DIR/nvm.sh" ] && \. "$NVM_DIR/nvm.sh"
+    [ -s "$NVM_DIR/bash_completion" ] && \. "$NVM_DIR/bash_completion"
+    
+    # Install Node.js 22 LTS
+    nvm install 22
+    nvm use 22
+    nvm alias default 22
+    
+    echo "✓ Node.js $(node -v) installed via NVM"
+    echo "✓ npm $(npm -v) available"
+else
+    echo "✓ Node.js already installed: $(node -v)"
+fi
+
+# Download xterm.js files
+echo "Downloading xterm.js..."
+chmod +x /root/whp/scripts/download-xterm.sh
+/root/whp/scripts/download-xterm.sh
+
+# Sync web files including xterm.js to document root
+echo "Syncing xterm.js files to web root..."
+rsync -av /root/whp/web-files/js/xterm/ /docker/whp/web/js/xterm/
+
+# Install terminal server dependencies
+echo "Installing terminal server dependencies..."
+cd /root/whp/terminal-server
+npm install --production
+
+# Copy Apache WebSocket configuration
+echo "Configuring Apache WebSocket proxy..."
+cp /root/whp/configs/whp-terminal-websocket.conf /etc/httpd/conf.d/
+
+# Install and enable systemd service
+echo "Installing terminal server service..."
+chmod +x /root/whp/scripts/create-terminal-service.sh
+/root/whp/scripts/create-terminal-service.sh
+systemctl daemon-reload
+systemctl enable whp-terminal
+systemctl start whp-terminal
+
+echo "✓ WebSocket Terminal Server configured"
+cd /root/whp
+
 echo "Setup completed!"
 echo ""
 echo "Access your control panel at: http://your-server-ip:8080"
@@ -475,6 +532,7 @@ echo "7. Use '/root/whp/scripts/powerdns-password-manager.sh' for DNS password m
 echo "8. Configure backup targets in the WHP control panel under 'Backup Management'"
 echo "9. WordPress auto-updates are configured to run every 6 hours (2 AM, 8 AM, 2 PM, 8 PM)"
 echo "10. WordPress security settings include comprehensive options: file editor blocking, XML-RPC protection, version hiding, security headers, and more"
+echo "11. WebSocket terminal server provides full terminal access to containers via the web interface"
 echo ""
 echo "Troubleshooting:"
 echo "- Check logs in /var/log/httpd/ for Apache issues"
@@ -483,6 +541,8 @@ echo "- Ensure .user.ini is copied to web directory if authentication fails"
 echo "- Check backup logs in /var/log/whp-backup-*.log"
 echo "- Check WordPress auto-update logs in /var/log/wordpress-auto-update.log"
 echo "- WordPress management includes WP-CLI integration, security settings, auto-updates, and backup functionality"
+echo "- Check terminal server logs: journalctl -u whp-terminal -f"
+echo "- Verify WebSocket proxy is working: check /terminal-ws endpoint"
 echo "REBOOT THE SERVER NOW"
 echo ""
 
